==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/3e/3e1e98bfb73f68264ea3317797c24307.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/DashboardBundle/Entity/WidgetRepository.php */
class __TwigTemplate_3d2006ca1fa68d40842448b5b408e108 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\DashboardBundle\\Entity;

use Mautic\\CoreBundle\\Entity\\CommonRepository;

/**
 * @extends CommonRepository<Widget>
 */
class WidgetRepository extends CommonRepository
{
    /**
     * Update widget ordering.
     *
     * @param array \$ordering
     * @param int   \$userId
     */
    public function updateOrdering(\$ordering, \$userId): void
    {
        \$widgets = \$this->getEntities(
            [
                'filter' => [
                    'createdBy' => \$userId,
                ],
            ]
        );

        foreach (\$widgets as &\$widget) {
            if (isset(\$ordering[\$widget->getId()])) {
                \$widget->setOrdering((int) \$ordering[\$widget->getId()]);
            }
        }

        \$this->saveEntities(\$widgets);
    }

    protected function getDefaultOrder(): array
    {
        return [
            ['w.ordering', 'ASC'],
        ];
    }

    public function getTableAlias(): string
    {
        return 'w';
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/DashboardBundle/Entity/WidgetRepository.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/DashboardBundle/Entity/WidgetRepository.php", "/var/www/mautic-ktn/app/bundles/DashboardBundle/Entity/WidgetRepository.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/3e/3e1e98bfb73f68264ea3317797c24307.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/DashboardBundle/Entity/WidgetRepository.php */
class __TwigTemplate_3d2006ca1fa68d40842448b5b408e108 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\DashboardBundle\\Entity;

use Mautic\\CoreBundle\\Entity\\CommonRepository;

/**
 * @extends CommonRepository<Widget>
 */
class WidgetRepository extends CommonRepository
{
    /**
     * Update widget ordering.
     *
     * @param array \$ordering
     * @param int   \$userId
     */
    public function updateOrdering(\$ordering, \$userId): void
    {
        \$widgets = \$this->getEntities(
            [
                'filter' => [
                    'createdBy' => \$userId,
                ],
            ]
        );

        foreach (\$widgets as &\$widget) {
            if (isset(\$ordering[\$widget->getId()])) {
                \$widget->setOrdering((int) \$ordering[\$widget->getId()]);
            }
        }

        \$this->saveEntities(\$widgets);
    }

    protected function getDefaultOrder(): array
    {
        return [
            ['w.ordering', 'ASC'],
        ];
    }

    public function getTableAlias(): string
    {
        return 'w';
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/DashboardBundle/Entity/WidgetRepository.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/DashboardBundle/Entity/WidgetRepository.php", "/var/www/html/mauticGIT-Test/app/bundles/DashboardBundle/Entity/WidgetRepository.php");
    }
}
